import { UseSnackbarParameters, UseSnackbarReturnValue } from "./useSnackbar.types.js";
declare function useSnackbar(parameters?: UseSnackbarParameters): UseSnackbarReturnValue;
export default useSnackbar;