/**
 * default MD color-schemes
 */

/**
 * The application can add more color-scheme by extending this interface via module augmentation
 *
 * Ex.
 * declare module @mui/material/styles {
 *   interface ColorSchemeOverrides {
 *     foo: true;
 *   }
 * }
 *
 * // SupportedColorScheme = 'light' | 'dark' | 'foo';
 */

/**
 * All color-schemes that the application has
 */

// The Palette should be sync with `../themeCssVarsAugmentation/index.d.ts`

// should not include keys defined in `shouldSkipGeneratingVar` and have value typeof function

/**
 * Does not work for these cases:
 * - { borderRadius: string | number } // the value can't be a union
 * - { shadows: [string, string, ..., string] } // the value can't be an array
 */

// shut off automatic exporting for the Generics above
export {};

/**
 * Theme properties generated by extendTheme and CssVarsProvider
 */