export { default } from "./Paper.js";
export type { PaperProps, PaperOwnProps, PaperPropsVariantOverrides, PaperTypeMap } from "./Paper.js";
export { default as paperClasses } from "./paperClasses.js";
export * from "./paperClasses.js";