import { PolymorphicComponent } from "../utils/PolymorphicComponent.js";
import { PopperTypeMap } from "./BasePopper.types.js";
/**
 * @ignore - internal component.
 */
declare const Popper: PolymorphicComponent<PopperTypeMap>;
export default Popper;