import * as React from 'react';
import { FocusTrapProps } from "./FocusTrap.types.js";
/**
 * @ignore - internal component.
 */
declare function FocusTrap(props: FocusTrapProps): React.JSX.Element;
declare namespace FocusTrap {
  var propTypes: any;
}
export default FocusTrap;