import * as React from 'react';
/**
 * @ignore - internal component.
 */
declare const ToggleButtonGroupButtonContext: React.Context<string | undefined>;
export default ToggleButtonGroupButtonContext;