import { UseSliderParameters, UseSliderReturnValue } from "./useSlider.types.js";
export declare function valueToPercent(value: number, min: number, max: number): number;
export declare const Identity: (x: any) => any;
export declare function useSlider(parameters: UseSliderParameters): UseSliderReturnValue;