export { default } from "./TablePaginationActions.js";
export * from "./TablePaginationActions.js";
export { default as tablePaginationActionsClasses } from "./tablePaginationActionsClasses.js";
export * from "./tablePaginationActionsClasses.js";