export declare const version: string | undefined;
export declare const major: number;
export declare const minor: number;
export declare const patch: number;
export declare const prerelease: string | undefined;
export default version;